/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2015   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 *  FILE: gabortest.cc
 *
 */


#include "image3d.h"
#include "descriptors/gabor.h"

using namespace std;
using namespace i3d;


int main(int argc, char* argv[])
{
	if ((argc != 5) ||
		(atoi(argv[2]) < 1) || (atoi(argv[2]) > 10) || 
		(atoi(argv[3]) < 2) || (atoi(argv[3]) > 10) || 
		(atoi(argv[4]) < 5) || (atoi(argv[4]) > 200))
	{
		cerr << "gabortest.cc ... evaluation of Gabor texture features \n\n"
		"Copyright (C) 2015 Centre for Biomedical Image Analysis \n"
		"This is free software; see the source for copying conditions. "
		"There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR "
		"A PARTICULAR PURPOSE.\n\n";
		cerr << "SYNTAX" << endl << "\t" << "gabortest.exe input_image <options> " << endl << endl;
		cerr << "OPTIONS" << endl <<
		"\t <int> ... number of scales (radial index), could be 1..10 \n" << endl;
		cerr << "\t <int> ... number of orientations (angular index), could be 2..16 \n " << endl;
		cerr << "\t <int> ... size of Gabor filter kernel, could be 5..200 \n " << endl;
		cerr << "EXAMPLE" << endl <<
		"gabortest.exe centromere-028-test-16-37-p.png 5 3 39" << endl << endl;
		exit(1);
	}		

	try  
	{
		ImgVoxelType vt = ReadImageType(argv[1]);
		switch (vt)
		{
			case Gray8Voxel: 
			{
				Image3d<GRAY8> img(argv[1]);
				  if (img.GetSizeZ() > 1) 
					  ComputeGabor3D(img, (GRAY8) atoi(argv[2]), (GRAY8) atoi(argv[3]), (GRAY8) atoi(argv[4]));
				  else 
					  ComputeGabor2D(img, (GRAY8) atoi(argv[2]), (GRAY8) atoi(argv[3]), (GRAY8) atoi(argv[4]));				  
				  break;
			}
			case Gray16Voxel: 
			{
				Image3d<GRAY16> img(argv[1]);
				  if (img.GetSizeZ() > 1) 
					  ComputeGabor3D(img, (GRAY16) atoi(argv[2]), (GRAY16) atoi(argv[3]), (GRAY16) atoi(argv[4]));
				  else 
					  ComputeGabor2D(img, (GRAY16) atoi(argv[2]), (GRAY16) atoi(argv[3]), (GRAY16) atoi(argv[4]));
				  break;
			}
			default: cerr << "wrong image type" << endl;
		}
	}
	catch (IOException& e) {
		cerr << e <<endl;
		exit(1);
	}
	catch (InternalException& e) {
		cerr << e <<endl;
		exit(1);
	}
	catch (bad_alloc&) {
		cerr << "Not enough memory." << endl;
		exit(1);
	}
	catch (...) {
		cerr << "gabortest: Unknown exception." << endl;
		exit(1);
	}

  return 0;
}