/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2015   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 *  FILE: lbptest.cc
 *
 */


#include "image3d.h"
#include "descriptors/lbp.h"

using namespace std;
using namespace i3d;


int main(int argc, char* argv[])
{
	if ((argc != 6) ||
		(atoi(argv[2]) < 1) || (atoi(argv[2]) > 16) || 
		(atoi(argv[3]) < 1) || (atoi(argv[3]) > 5) || 
		(atoi(argv[4]) < 1) || (atoi(argv[4]) > 5) ||
		(atoi(argv[5]) < 1) || (atoi(argv[5]) > 5))
	{
		cerr << "lbptest.cc ... evaluation of Local Binary Patterns \n\n"
		"Copyright (C) 2015 Centre for Biomedical Image Analysis \n"
		"This is free software; see the source for copying conditions. "
		"There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR "
		"A PARTICULAR PURPOSE.\n\n";
		cerr << "SYNTAX" << endl << "\t" << "lbptest.exe input_image <options> " << endl << endl;
		cerr << "OPTIONS" << endl;
		cerr << "\t <int> ... number of samples (how many points to take around the circle), optimal 8 or 4 \n" << endl;
		cerr << "\t <int> ... radius of the first circle from the central pixel, optimal 1 \n " << endl;
		cerr << "\t <int> ... increase of the radius, optimal is 2 \n " << endl;
		cerr << "\t <int> ... number of radiuses used, optimal is 1, 2, or 3 \n " << endl;
		cerr << "EXAMPLE" << endl <<
		"lbptest.exe centromere-028-test-16-37-p.png 8 1 2 1" << endl << endl;
		exit(1);
	}		

	try  
	{
		ImgVoxelType vt = ReadImageType(argv[1]);
		switch (vt)
		{
			case Gray8Voxel: 
			{
				Image3d<GRAY8> img(argv[1]);
				  if (img.GetSizeZ() > 1) 
				  {
					  cerr << "lbptest.exe is for 2D images only. For 3D images use vlbptest, lbptoptest, or lbpplaton." << endl;
					  exit(1);
				  }
				  else 
					  ComputeLBP(img, (GRAY8) atoi(argv[2]), (GRAY8) atoi(argv[3]), (GRAY8) atoi(argv[4]), (GRAY8) atoi(argv[5]));				  
				  break;
			}
			case Gray16Voxel: 
			{
				Image3d<GRAY16> img(argv[1]);
				  if (img.GetSizeZ() > 1) 
				  {
					  cerr << "lbptest.exe is for 2D images only. For 3D images use vlbptest, lbptoptest, or lbpplaton." << endl;
					  exit(1);
				  }
				  else 
					  ComputeLBP(img, (GRAY16) atoi(argv[2]), (GRAY16) atoi(argv[3]), (GRAY16) atoi(argv[4]), (GRAY16) atoi(argv[5]));
				  break;
			}
			default: cerr << "wrong image type" << endl;
		}
	}
	catch (IOException& e) {
		cerr << e <<endl;
		exit(1);
	}
	catch (InternalException& e) {
		cerr << e <<endl;
		exit(1);
	}
	catch (bad_alloc&) {
		cerr << "Not enough memory." << endl;
		exit(1);
	}
	catch (...) {
		cerr << "lbptest: Unknown exception." << endl;
		exit(1);
	}

  return 0;
}