/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2006   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * nha_neighbourhood.cc
 *
 * Neighbourhood used in the Nilsson-Heyden algorithm
 *
 * Martin Maka (xmaska@fi.muni.cz) 2006 - 2011
 */

#include "nha_neighbourhood.h"

namespace i3d
{
	namespace fls
	{
		/////////////////////////////////////////////////////////////////
		//                                                             //
		//                    Class NHA_Neighbourhood                  //
		//                                                             //
		/////////////////////////////////////////////////////////////////

		/**********************************************************************/

		NHA_Neighbourhood::NHA_Neighbourhood(const Grid<int> &grid, NeighbourIndices *neigh_indices, const NHA_Predicate *pred_internal, const NHA_Predicate *pred_external)
			: m_grid(grid), m_neigh_indices(neigh_indices), m_pred_internal(pred_internal), m_pred_external(pred_external), m_buffer(NULL) 
		{
			m_buffer = new Type::Size[neigh_indices -> Number()];
		}

		/**********************************************************************/

		NHA_Neighbourhood::~NHA_Neighbourhood()

		{ 
			delete m_neigh_indices; 
			delete m_pred_internal; 
			delete m_pred_external; 
			delete [] m_buffer;
		}

		/**********************************************************************/

		Type::Size NHA_Neighbourhood::NumAvail(Type::Size i)
		{
			Type::Size num = 0;

			Type::Size num_neigh;
			const Type::Size *indices = m_neigh_indices -> Indices(i, num_neigh);

			for (Type::Size j = 0; j < num_neigh; ++j)
			{
				if (m_grid.m_implicit_function[indices[j]] > 0)
				{
					++num;
				}
			}

			return num;
		}

		/**********************************************************************/

		const Type::Size *NHA_Neighbourhood::Neighbours(Type::Size i, const NHA_Predicate *pred, Type::Size &num)
		{
			Type::Size num_neigh;
			const Type::Size *indices = m_neigh_indices -> Indices(i, num_neigh);

			num = 0;

			for (Type::Size j = 0; j < num_neigh; ++j)
			{
				if ((*pred)(m_grid.m_implicit_function[indices[j]]))
				{
					m_buffer[num] = indices[j];
					++num;
				}
			}

			return m_buffer;
		}

		/**********************************************************************/

	} // namespace fls 

} // namespace i3d

