/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2006   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * profiler.h
 *
 * Profiler
 *
 * Martin Maka (xmaska@fi.muni.cz) 2006 - 2011
 */

#include <stdio.h>
#include "profiler.h"

namespace i3d
{
	namespace fls
	{
		/////////////////////////////////////////////////////////////////
		//                                                             //
		//                      Class Profiler                         //
		//                                                             //
		/////////////////////////////////////////////////////////////////

		/**********************************************************************/

		void Profiler::Start()
		{
			++m_num;
			m_start = clock();
		}

		/**********************************************************************/

		void Profiler::Finish()
		{
			clock_t time = clock() - m_start;

			if (m_num == 1)
			{
				m_min = time;
				m_max = time;
			}
			else
			{
				if (time < m_min)
				{
					m_min = time;
				}

				if (time > m_max)
				{
					m_max = time;
				}
			}

			m_total += time;
		}

		/**********************************************************************/

		void Profiler::Report() const
		{
			printf("%s: Num %d Total %.3f Min %.3f Max %.3f\n", 
				m_name, m_num, m_total / Type::Prec(CLOCKS_PER_SEC), m_min / Type::Prec(CLOCKS_PER_SEC), m_max / Type::Prec(CLOCKS_PER_SEC));
		}

		/**********************************************************************/

	} // namespace fls

} // namespace i3d

