/*
 * i3dlib - image manipulation library
 *
 * Copyright (C) 2000-2006   Centre for Biomedical Image Analysis (CBIA)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/** \file watersheds_internal.cc
  \brief Part of mathematical morphology routines - implementation.

  This file contains bodies of mathematical morphology routines dealing with 
  the internal support functions for the watershed transformations.
*/ 

#include "morphology.h"
#include "draw.h"


#ifdef __GNUG__
#	pragma implementation
#endif

namespace i3d {

	//--------------------------------------------------------------------------
	// various watershed algorithms support functions
	//--------------------------------------------------------------------------

	template <typename T>
	I3D_ALGO_EXPORT void WSInternalMarkerFromMinima(const Image3d<T> &input, Image3d<size_t> &marker, const Neighbourhood &neighbourhood)
	{
		Image3d<T> markerT;
		markerT.CopyMetaData(input);
		r_Min(input, markerT, neighbourhood);
		marker.CopyMetaData(input);
		marker.SetAllVoxels(0);
		size_t label = 1;
		size_t imageSize = markerT.GetImageSize();
		for (size_t i = 0; i < imageSize; ++i)
		{
			if (marker.GetVoxel(i) == 0 && markerT.GetVoxel(i) == std::numeric_limits<T>::max())
				FloodFill(markerT, marker, label++, i, neighbourhood);
		}
	}

	template I3D_ALGO_EXPORT void WSInternalMarkerFromMinima(const Image3d<i3d::GRAY8> &input, Image3d<size_t> &marker, const Neighbourhood &neighbourhood);
	template I3D_ALGO_EXPORT void WSInternalMarkerFromMinima(const Image3d<i3d::GRAY16> &input, Image3d<size_t> &marker, const Neighbourhood &neighbourhood);
	template I3D_ALGO_EXPORT void WSInternalMarkerFromMinima(const Image3d<float> &input, Image3d<size_t> &marker, const Neighbourhood &neighbourhood);

} // namespace i3d
